# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: commands/v1/commands.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ... import governance_pb2 as governance__pb2
from ... import vega_pb2 as vega__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from ...github.com.mwitkow.go_proto_validators import validator_pb2 as github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='commands/v1/commands.proto',
  package='vega.commands.v1',
  syntax='proto3',
  serialized_options=b'\n io.vegaprotocol.vega.commands.v1Z+code.vegaprotocol.io/vega/proto/commands/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x63ommands/v1/commands.proto\x12\x10vega.commands.v1\x1a\x10governance.proto\x1a\nvega.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x36github.com/mwitkow/go-proto-validators/validator.proto\"\xde\x02\n\x0fOrderSubmission\x12#\n\tmarket_id\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x08marketId\x12\x14\n\x05price\x18\x02 \x01(\x04R\x05price\x12\x1a\n\x04size\x18\x03 \x01(\x04\x42\x06\xe2\xdf\x1f\x02\x10\x00R\x04size\x12\x1e\n\x04side\x18\x04 \x01(\x0e\x32\n.vega.SideR\x04side\x12;\n\rtime_in_force\x18\x05 \x01(\x0e\x32\x17.vega.Order.TimeInForceR\x0btimeInForce\x12\x1d\n\nexpires_at\x18\x06 \x01(\x03R\texpiresAt\x12$\n\x04type\x18\x07 \x01(\x0e\x32\x10.vega.Order.TypeR\x04type\x12\x1c\n\treference\x18\x08 \x01(\tR\treference\x12\x34\n\x0cpegged_order\x18\t \x01(\x0b\x32\x11.vega.PeggedOrderR\x0bpeggedOrder\"K\n\x11OrderCancellation\x12\x19\n\x08order_id\x18\x01 \x01(\tR\x07orderId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\"\x83\x03\n\x0eOrderAmendment\x12!\n\x08order_id\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x07orderId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12!\n\x05price\x18\x03 \x01(\x0b\x32\x0b.vega.PriceR\x05price\x12\x1d\n\nsize_delta\x18\x04 \x01(\x03R\tsizeDelta\x12.\n\nexpires_at\x18\x05 \x01(\x0b\x32\x0f.vega.TimestampR\texpiresAt\x12;\n\rtime_in_force\x18\x06 \x01(\x0e\x32\x17.vega.Order.TimeInForceR\x0btimeInForce\x12@\n\rpegged_offset\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x0cpeggedOffset\x12@\n\x10pegged_reference\x18\x08 \x01(\x0e\x32\x15.vega.PeggedReferenceR\x0fpeggedReference\"\xf6\x01\n\x1cLiquidityProvisionSubmission\x12#\n\tmarket_id\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\x08marketId\x12+\n\x11\x63ommitment_amount\x18\x02 \x01(\x04R\x10\x63ommitmentAmount\x12\x10\n\x03\x66\x65\x65\x18\x03 \x01(\tR\x03\x66\x65\x65\x12*\n\x05sells\x18\x04 \x03(\x0b\x32\x14.vega.LiquidityOrderR\x05sells\x12(\n\x04\x62uys\x18\x05 \x03(\x0b\x32\x14.vega.LiquidityOrderR\x04\x62uys\x12\x1c\n\treference\x18\x06 \x01(\tR\treference\"g\n\x12WithdrawSubmission\x12\x16\n\x06\x61mount\x18\x01 \x01(\x04R\x06\x61mount\x12\x14\n\x05\x61sset\x18\x02 \x01(\tR\x05\x61sset\x12#\n\x03\x65xt\x18\x03 \x01(\x0b\x32\x11.vega.WithdrawExtR\x03\x65xt\"e\n\x12ProposalSubmission\x12\x1c\n\treference\x18\x01 \x01(\tR\treference\x12\x31\n\x05terms\x18\x02 \x01(\x0b\x32\x13.vega.ProposalTermsB\x06\xe2\xdf\x1f\x02 \x01R\x05terms\"a\n\x0eVoteSubmission\x12\'\n\x0bproposal_id\x18\x01 \x01(\tB\x06\xe2\xdf\x1f\x02X\x01R\nproposalId\x12&\n\x05value\x18\x02 \x01(\x0e\x32\x10.vega.Vote.ValueR\x05valueBO\n io.vegaprotocol.vega.commands.v1Z+code.vegaprotocol.io/vega/proto/commands/v1b\x06proto3'
  ,
  dependencies=[governance__pb2.DESCRIPTOR,vega__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,github_dot_com_dot_mwitkow_dot_go__proto__validators_dot_validator__pb2.DESCRIPTOR,])




_ORDERSUBMISSION = _descriptor.Descriptor(
  name='OrderSubmission',
  full_name='vega.commands.v1.OrderSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.commands.v1.OrderSubmission.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='vega.commands.v1.OrderSubmission.price', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='price', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='vega.commands.v1.OrderSubmission.size', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002\020\000', json_name='size', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='side', full_name='vega.commands.v1.OrderSubmission.side', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='side', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_in_force', full_name='vega.commands.v1.OrderSubmission.time_in_force', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeInForce', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='vega.commands.v1.OrderSubmission.expires_at', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='expiresAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='vega.commands.v1.OrderSubmission.type', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='type', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.commands.v1.OrderSubmission.reference', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pegged_order', full_name='vega.commands.v1.OrderSubmission.pegged_order', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peggedOrder', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=517,
)


_ORDERCANCELLATION = _descriptor.Descriptor(
  name='OrderCancellation',
  full_name='vega.commands.v1.OrderCancellation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='vega.commands.v1.OrderCancellation.order_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.commands.v1.OrderCancellation.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=519,
  serialized_end=594,
)


_ORDERAMENDMENT = _descriptor.Descriptor(
  name='OrderAmendment',
  full_name='vega.commands.v1.OrderAmendment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='order_id', full_name='vega.commands.v1.OrderAmendment.order_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='orderId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.commands.v1.OrderAmendment.market_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='price', full_name='vega.commands.v1.OrderAmendment.price', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='price', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size_delta', full_name='vega.commands.v1.OrderAmendment.size_delta', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sizeDelta', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expires_at', full_name='vega.commands.v1.OrderAmendment.expires_at', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='expiresAt', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_in_force', full_name='vega.commands.v1.OrderAmendment.time_in_force', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='timeInForce', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pegged_offset', full_name='vega.commands.v1.OrderAmendment.pegged_offset', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peggedOffset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pegged_reference', full_name='vega.commands.v1.OrderAmendment.pegged_reference', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='peggedReference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=597,
  serialized_end=984,
)


_LIQUIDITYPROVISIONSUBMISSION = _descriptor.Descriptor(
  name='LiquidityProvisionSubmission',
  full_name='vega.commands.v1.LiquidityProvisionSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='market_id', full_name='vega.commands.v1.LiquidityProvisionSubmission.market_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='marketId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commitment_amount', full_name='vega.commands.v1.LiquidityProvisionSubmission.commitment_amount', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='commitmentAmount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='vega.commands.v1.LiquidityProvisionSubmission.fee', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fee', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sells', full_name='vega.commands.v1.LiquidityProvisionSubmission.sells', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sells', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buys', full_name='vega.commands.v1.LiquidityProvisionSubmission.buys', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='buys', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.commands.v1.LiquidityProvisionSubmission.reference', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=987,
  serialized_end=1233,
)


_WITHDRAWSUBMISSION = _descriptor.Descriptor(
  name='WithdrawSubmission',
  full_name='vega.commands.v1.WithdrawSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='vega.commands.v1.WithdrawSubmission.amount', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='amount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='asset', full_name='vega.commands.v1.WithdrawSubmission.asset', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='asset', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ext', full_name='vega.commands.v1.WithdrawSubmission.ext', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='ext', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1235,
  serialized_end=1338,
)


_PROPOSALSUBMISSION = _descriptor.Descriptor(
  name='ProposalSubmission',
  full_name='vega.commands.v1.ProposalSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='reference', full_name='vega.commands.v1.ProposalSubmission.reference', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='reference', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='terms', full_name='vega.commands.v1.ProposalSubmission.terms', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002 \001', json_name='terms', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1340,
  serialized_end=1441,
)


_VOTESUBMISSION = _descriptor.Descriptor(
  name='VoteSubmission',
  full_name='vega.commands.v1.VoteSubmission',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='proposal_id', full_name='vega.commands.v1.VoteSubmission.proposal_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342\337\037\002X\001', json_name='proposalId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='vega.commands.v1.VoteSubmission.value', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1443,
  serialized_end=1540,
)

_ORDERSUBMISSION.fields_by_name['side'].enum_type = vega__pb2._SIDE
_ORDERSUBMISSION.fields_by_name['time_in_force'].enum_type = vega__pb2._ORDER_TIMEINFORCE
_ORDERSUBMISSION.fields_by_name['type'].enum_type = vega__pb2._ORDER_TYPE
_ORDERSUBMISSION.fields_by_name['pegged_order'].message_type = vega__pb2._PEGGEDORDER
_ORDERAMENDMENT.fields_by_name['price'].message_type = vega__pb2._PRICE
_ORDERAMENDMENT.fields_by_name['expires_at'].message_type = vega__pb2._TIMESTAMP
_ORDERAMENDMENT.fields_by_name['time_in_force'].enum_type = vega__pb2._ORDER_TIMEINFORCE
_ORDERAMENDMENT.fields_by_name['pegged_offset'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_ORDERAMENDMENT.fields_by_name['pegged_reference'].enum_type = vega__pb2._PEGGEDREFERENCE
_LIQUIDITYPROVISIONSUBMISSION.fields_by_name['sells'].message_type = vega__pb2._LIQUIDITYORDER
_LIQUIDITYPROVISIONSUBMISSION.fields_by_name['buys'].message_type = vega__pb2._LIQUIDITYORDER
_WITHDRAWSUBMISSION.fields_by_name['ext'].message_type = vega__pb2._WITHDRAWEXT
_PROPOSALSUBMISSION.fields_by_name['terms'].message_type = governance__pb2._PROPOSALTERMS
_VOTESUBMISSION.fields_by_name['value'].enum_type = governance__pb2._VOTE_VALUE
DESCRIPTOR.message_types_by_name['OrderSubmission'] = _ORDERSUBMISSION
DESCRIPTOR.message_types_by_name['OrderCancellation'] = _ORDERCANCELLATION
DESCRIPTOR.message_types_by_name['OrderAmendment'] = _ORDERAMENDMENT
DESCRIPTOR.message_types_by_name['LiquidityProvisionSubmission'] = _LIQUIDITYPROVISIONSUBMISSION
DESCRIPTOR.message_types_by_name['WithdrawSubmission'] = _WITHDRAWSUBMISSION
DESCRIPTOR.message_types_by_name['ProposalSubmission'] = _PROPOSALSUBMISSION
DESCRIPTOR.message_types_by_name['VoteSubmission'] = _VOTESUBMISSION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OrderSubmission = _reflection.GeneratedProtocolMessageType('OrderSubmission', (_message.Message,), {
  'DESCRIPTOR' : _ORDERSUBMISSION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.OrderSubmission)
  })
_sym_db.RegisterMessage(OrderSubmission)

OrderCancellation = _reflection.GeneratedProtocolMessageType('OrderCancellation', (_message.Message,), {
  'DESCRIPTOR' : _ORDERCANCELLATION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.OrderCancellation)
  })
_sym_db.RegisterMessage(OrderCancellation)

OrderAmendment = _reflection.GeneratedProtocolMessageType('OrderAmendment', (_message.Message,), {
  'DESCRIPTOR' : _ORDERAMENDMENT,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.OrderAmendment)
  })
_sym_db.RegisterMessage(OrderAmendment)

LiquidityProvisionSubmission = _reflection.GeneratedProtocolMessageType('LiquidityProvisionSubmission', (_message.Message,), {
  'DESCRIPTOR' : _LIQUIDITYPROVISIONSUBMISSION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.LiquidityProvisionSubmission)
  })
_sym_db.RegisterMessage(LiquidityProvisionSubmission)

WithdrawSubmission = _reflection.GeneratedProtocolMessageType('WithdrawSubmission', (_message.Message,), {
  'DESCRIPTOR' : _WITHDRAWSUBMISSION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.WithdrawSubmission)
  })
_sym_db.RegisterMessage(WithdrawSubmission)

ProposalSubmission = _reflection.GeneratedProtocolMessageType('ProposalSubmission', (_message.Message,), {
  'DESCRIPTOR' : _PROPOSALSUBMISSION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.ProposalSubmission)
  })
_sym_db.RegisterMessage(ProposalSubmission)

VoteSubmission = _reflection.GeneratedProtocolMessageType('VoteSubmission', (_message.Message,), {
  'DESCRIPTOR' : _VOTESUBMISSION,
  '__module__' : 'commands.v1.commands_pb2'
  # @@protoc_insertion_point(class_scope:vega.commands.v1.VoteSubmission)
  })
_sym_db.RegisterMessage(VoteSubmission)


DESCRIPTOR._options = None
_ORDERSUBMISSION.fields_by_name['market_id']._options = None
_ORDERSUBMISSION.fields_by_name['size']._options = None
_ORDERAMENDMENT.fields_by_name['order_id']._options = None
_LIQUIDITYPROVISIONSUBMISSION.fields_by_name['market_id']._options = None
_PROPOSALSUBMISSION.fields_by_name['terms']._options = None
_VOTESUBMISSION.fields_by_name['proposal_id']._options = None
# @@protoc_insertion_point(module_scope)
