# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: wallet/v1/wallet.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...commands.v1 import commands_pb2 as commands_dot_v1_dot_commands__pb2
from ...commands.v1 import validator_commands_pb2 as commands_dot_v1_dot_validator__commands__pb2
from ...commands.v1 import oracles_pb2 as commands_dot_v1_dot_oracles__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='wallet/v1/wallet.proto',
  package='vega.wallet.v1',
  syntax='proto3',
  serialized_options=b'\n\036io.vegaprotocol.vega.wallet.v1Z)code.vegaprotocol.io/vega/proto/wallet/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16wallet/v1/wallet.proto\x12\x0evega.wallet.v1\x1a\x1a\x63ommands/v1/commands.proto\x1a$commands/v1/validator_commands.proto\x1a\x19\x63ommands/v1/oracles.proto\"\xcb\x08\n\x18SubmitTransactionRequest\x12\x17\n\x07pub_key\x18\x01 \x01(\tR\x06pubKey\x12\x1c\n\tpropagate\x18\x02 \x01(\x08R\tpropagate\x12O\n\x10order_submission\x18\xe9\x07 \x01(\x0b\x32!.vega.commands.v1.OrderSubmissionH\x00R\x0forderSubmission\x12U\n\x12order_cancellation\x18\xea\x07 \x01(\x0b\x32#.vega.commands.v1.OrderCancellationH\x00R\x11orderCancellation\x12L\n\x0forder_amendment\x18\xeb\x07 \x01(\x0b\x32 .vega.commands.v1.OrderAmendmentH\x00R\x0eorderAmendment\x12X\n\x13withdraw_submission\x18\xec\x07 \x01(\x0b\x32$.vega.commands.v1.WithdrawSubmissionH\x00R\x12withdrawSubmission\x12X\n\x13proposal_submission\x18\xed\x07 \x01(\x0b\x32$.vega.commands.v1.ProposalSubmissionH\x00R\x12proposalSubmission\x12L\n\x0fvote_submission\x18\xee\x07 \x01(\x0b\x32 .vega.commands.v1.VoteSubmissionH\x00R\x0evoteSubmission\x12w\n\x1eliquidity_provision_submission\x18\xef\x07 \x01(\x0b\x32..vega.commands.v1.LiquidityProvisionSubmissionH\x00R\x1cliquidityProvisionSubmission\x12R\n\x11node_registration\x18\xd1\x0f \x01(\x0b\x32\".vega.commands.v1.NodeRegistrationH\x00R\x10nodeRegistration\x12:\n\tnode_vote\x18\xd2\x0f \x01(\x0b\x32\x1a.vega.commands.v1.NodeVoteH\x00R\x08nodeVote\x12I\n\x0enode_signature\x18\xd3\x0f \x01(\x0b\x32\x1f.vega.commands.v1.NodeSignatureH\x00R\rnodeSignature\x12@\n\x0b\x63hain_event\x18\xd4\x0f \x01(\x0b\x32\x1c.vega.commands.v1.ChainEventH\x00R\nchainEvent\x12_\n\x16oracle_data_submission\x18\xb9\x17 \x01(\x0b\x32&.vega.commands.v1.OracleDataSubmissionH\x00R\x14oracleDataSubmissionB\t\n\x07\x63ommandBK\n\x1eio.vegaprotocol.vega.wallet.v1Z)code.vegaprotocol.io/vega/proto/wallet/v1b\x06proto3'
  ,
  dependencies=[commands_dot_v1_dot_commands__pb2.DESCRIPTOR,commands_dot_v1_dot_validator__commands__pb2.DESCRIPTOR,commands_dot_v1_dot_oracles__pb2.DESCRIPTOR,])




_SUBMITTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='SubmitTransactionRequest',
  full_name='vega.wallet.v1.SubmitTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='pub_key', full_name='vega.wallet.v1.SubmitTransactionRequest.pub_key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pubKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='propagate', full_name='vega.wallet.v1.SubmitTransactionRequest.propagate', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='propagate', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.order_submission', index=2,
      number=1001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_cancellation', full_name='vega.wallet.v1.SubmitTransactionRequest.order_cancellation', index=3,
      number=1002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderCancellation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='order_amendment', full_name='vega.wallet.v1.SubmitTransactionRequest.order_amendment', index=4,
      number=1003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='orderAmendment', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='withdraw_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.withdraw_submission', index=5,
      number=1004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withdrawSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proposal_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.proposal_submission', index=6,
      number=1005, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='proposalSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vote_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.vote_submission', index=7,
      number=1006, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='voteSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='liquidity_provision_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.liquidity_provision_submission', index=8,
      number=1007, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='liquidityProvisionSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_registration', full_name='vega.wallet.v1.SubmitTransactionRequest.node_registration', index=9,
      number=2001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeRegistration', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_vote', full_name='vega.wallet.v1.SubmitTransactionRequest.node_vote', index=10,
      number=2002, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeVote', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_signature', full_name='vega.wallet.v1.SubmitTransactionRequest.node_signature', index=11,
      number=2003, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nodeSignature', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_event', full_name='vega.wallet.v1.SubmitTransactionRequest.chain_event', index=12,
      number=2004, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='chainEvent', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oracle_data_submission', full_name='vega.wallet.v1.SubmitTransactionRequest.oracle_data_submission', index=13,
      number=3001, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='oracleDataSubmission', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='command', full_name='vega.wallet.v1.SubmitTransactionRequest.command',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=136,
  serialized_end=1235,
)

_SUBMITTRANSACTIONREQUEST.fields_by_name['order_submission'].message_type = commands_dot_v1_dot_commands__pb2._ORDERSUBMISSION
_SUBMITTRANSACTIONREQUEST.fields_by_name['order_cancellation'].message_type = commands_dot_v1_dot_commands__pb2._ORDERCANCELLATION
_SUBMITTRANSACTIONREQUEST.fields_by_name['order_amendment'].message_type = commands_dot_v1_dot_commands__pb2._ORDERAMENDMENT
_SUBMITTRANSACTIONREQUEST.fields_by_name['withdraw_submission'].message_type = commands_dot_v1_dot_commands__pb2._WITHDRAWSUBMISSION
_SUBMITTRANSACTIONREQUEST.fields_by_name['proposal_submission'].message_type = commands_dot_v1_dot_commands__pb2._PROPOSALSUBMISSION
_SUBMITTRANSACTIONREQUEST.fields_by_name['vote_submission'].message_type = commands_dot_v1_dot_commands__pb2._VOTESUBMISSION
_SUBMITTRANSACTIONREQUEST.fields_by_name['liquidity_provision_submission'].message_type = commands_dot_v1_dot_commands__pb2._LIQUIDITYPROVISIONSUBMISSION
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_registration'].message_type = commands_dot_v1_dot_validator__commands__pb2._NODEREGISTRATION
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_vote'].message_type = commands_dot_v1_dot_validator__commands__pb2._NODEVOTE
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_signature'].message_type = commands_dot_v1_dot_validator__commands__pb2._NODESIGNATURE
_SUBMITTRANSACTIONREQUEST.fields_by_name['chain_event'].message_type = commands_dot_v1_dot_validator__commands__pb2._CHAINEVENT
_SUBMITTRANSACTIONREQUEST.fields_by_name['oracle_data_submission'].message_type = commands_dot_v1_dot_oracles__pb2._ORACLEDATASUBMISSION
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['order_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['order_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['order_cancellation'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['order_cancellation'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['order_amendment'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['order_amendment'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['withdraw_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['withdraw_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['proposal_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['proposal_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['vote_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['vote_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['liquidity_provision_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['liquidity_provision_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['node_registration'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_registration'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['node_vote'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_vote'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['node_signature'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['node_signature'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['chain_event'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['chain_event'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
_SUBMITTRANSACTIONREQUEST.oneofs_by_name['command'].fields.append(
  _SUBMITTRANSACTIONREQUEST.fields_by_name['oracle_data_submission'])
_SUBMITTRANSACTIONREQUEST.fields_by_name['oracle_data_submission'].containing_oneof = _SUBMITTRANSACTIONREQUEST.oneofs_by_name['command']
DESCRIPTOR.message_types_by_name['SubmitTransactionRequest'] = _SUBMITTRANSACTIONREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SubmitTransactionRequest = _reflection.GeneratedProtocolMessageType('SubmitTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SUBMITTRANSACTIONREQUEST,
  '__module__' : 'wallet.v1.wallet_pb2'
  # @@protoc_insertion_point(class_scope:vega.wallet.v1.SubmitTransactionRequest)
  })
_sym_db.RegisterMessage(SubmitTransactionRequest)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
